summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorUnknwon <u@gogs.io>2016-08-30 15:19:53 -0700
committerUnknwon <u@gogs.io>2016-08-30 15:19:53 -0700
commit43297148b22b976d9cec0c56c863a704f3691c0e (patch)
tree230bce7c66ae688c447684357bf8bd7cc0315211
parentc0c1a4b01b4dee3cc85d26f4081ff0a456a16b38 (diff)
downloadgitea-43297148b22b976d9cec0c56c863a704f3691c0e.tar.gz
gitea-43297148b22b976d9cec0c56c863a704f3691c0e.zip
modules/sync: rename SingleInstancePool to ExclusivePool
-rw-r--r--models/repo.go2
-rw-r--r--models/wiki.go2
-rw-r--r--modules/sync/exclusive_pool.go (renamed from modules/sync/single_instance_pool.go)19
3 files changed, 12 insertions, 11 deletions
diff --git a/models/repo.go b/models/repo.go
index a26ba92482..8c6f86dafc 100644
--- a/models/repo.go
+++ b/models/repo.go
@@ -40,7 +40,7 @@ const (
_TPL_UPDATE_HOOK = "#!/usr/bin/env %s\n%s update $1 $2 $3 --config='%s'\n"
)
-var repoWorkingPool = sync.NewSingleInstancePool()
+var repoWorkingPool = sync.NewExclusivePool()
var (
ErrRepoFileNotExist = errors.New("Repository file does not exist")
diff --git a/models/wiki.go b/models/wiki.go
index f62cd2ac79..bc8aaf666e 100644
--- a/models/wiki.go
+++ b/models/wiki.go
@@ -21,7 +21,7 @@ import (
"github.com/gogits/gogs/modules/sync"
)
-var wikiWorkingPool = sync.NewSingleInstancePool()
+var wikiWorkingPool = sync.NewExclusivePool()
// ToWikiPageURL formats a string to corresponding wiki URL name.
func ToWikiPageURL(name string) string {
diff --git a/modules/sync/single_instance_pool.go b/modules/sync/exclusive_pool.go
index 01d95fd0b5..744cc7c996 100644
--- a/modules/sync/single_instance_pool.go
+++ b/modules/sync/exclusive_pool.go
@@ -8,14 +8,15 @@ import (
"sync"
)
// SingleInstancePool is a pool of non-identical instances
// that only one instance with same identity is in the pool at a time.
-// In other words, only instances with different identities can exist
-// at the same time.
+// In other words, only instances with different identities can be in
+// the pool the same time. If another instance with same identity tries
+// to get into the pool, it hangs until previous instance left the pool.
//
// This pool is particularly useful for performing tasks on same resource
// on the file system in different goroutines.
-type SingleInstancePool struct {
+type ExclusivePool struct {
lock sync.Mutex
// pool maintains locks for each instance in the pool.
@@ -29,9 +30,9 @@ type SingleInstancePool struct {
count map[string]int
}
-// NewSingleInstancePool initializes and returns a new SingleInstancePool object.
-func NewSingleInstancePool() *SingleInstancePool {
- return &SingleInstancePool{
+// NewExclusivePool initializes and returns a new ExclusivePool object.
+func NewExclusivePool() *ExclusivePool {
+ return &ExclusivePool{
pool: make(map[string]*sync.Mutex),
count: make(map[string]int),
}
@@ -39,7 +40,7 @@ func NewSingleInstancePool() *SingleInstancePool {
// CheckIn checks in an instance to the pool and hangs while instance
// with same indentity is using the lock.
-func (p *SingleInstancePool) CheckIn(identity string) {
+func (p *ExclusivePool) CheckIn(identity string) {
p.lock.Lock()
lock, has := p.pool[identity]
@@ -55,7 +56,7 @@ func (p *SingleInstancePool) CheckIn(identity string) {
// CheckOut checks out an instance from the pool and releases the lock
// to let other instances with same identity to grab the lock.
-func (p *SingleInstancePool) CheckOut(identity string) {
+func (p *ExclusivePool) CheckOut(identity string) {
p.lock.Lock()
defer p.lock.Unlock()
@@ -8,14 +8,15 @@ import (
"sync"
)
-// SingleInstancePool is a pool of non-identical instances
+// ExclusivePool is a pool of non-identical instances
// that only one instance with same identity is in the pool at a time.